Welcome to Aurora Documentation
===================================

.. image:: figures/aurora_logo.png
   :width: 900
   :alt: AURORA

.. aurora documentation master file, created by
   sphinx-quickstart on Sun Aug 22 14:43:40 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   user-docs/installing

.. toctree::
   :maxdepth: 2
   :caption: Examples

   examples/operate_aurora.ipynb
   examples/dataset_definition.ipynb

.. toctree::
   :maxdepth: 2
   :caption: Tutorials
   
   tutorials/processing_configuration.ipynb
   tutorials/earthscope_magnetic_data_tutorial.ipynb
   tutorials/process_cas04_multiple_station.ipynb
   tutorials/synthetic_data_processing.ipynb

.. toctree::
   :maxdepth: 4
   :caption: Reference documentation

   api/modules.rst

.. include:: ../CONTRIBUTING.rst
